This function creates a CODEOWNERS file in the folder .github/. This
file is used to define individual that is responsible for code in the
repository.
Arguments
- github_user
a
characterof length 1. The GitHub account name of the user (considered as the maintainer and code owner of the project).- open
A logical value. If
TRUE(default) the file is opened in the editor.- overwrite
A logical value. If this file is already present and
overwrite = TRUE, it will be erased and replaced. Default isFALSE.- quiet
A logical value. If
TRUEmessages are deleted. Default isFALSE.