Skip to contents

This function creates a CONTRIBUTING.md file providing general guidelines outlining the best way to contribute to the project (need to be adapted).

Usage

add_contributing(
  email = NULL,
  organisation = NULL,
  open = TRUE,
  overwrite = FALSE,
  quiet = FALSE
)

Arguments

email

A character of length 1. The email address of the project maintainer.

organisation

A character of length 1. The name of the GitHub organisation to host the package. If NULL (default) the GitHub account will be used. This argument is used to set the URL of the package (hosted on GitHub).

open

A logical value. If TRUE (default) the file is opened in the editor.

overwrite

A logical value. If this file is already present and overwrite = TRUE, it will be erased and replaced. Default is FALSE.

quiet

A logical value. If TRUE messages are deleted. Default is FALSE.

Value

No return value.

Examples

if (FALSE) { # \dontrun{
add_contributing()
} # }