Skip to contents

This function adds a CRAN total download badge to the README.Rmd.

Make sure that 1) a README.Rmd file exists at the project root and 2) it contains a block starting with the line <!-- badges: start --> and ending with the line <!-- badges: end -->.

Don't forget to re-render the README.md.

Usage

add_cran_total_download_badge(quiet = FALSE)

Arguments

quiet

A logical value. If TRUE messages are deleted. Default is FALSE.

Value

A badge as a markdown expression.

Examples

if (FALSE) { # \dontrun{
add_cran_total_download_badge()
} # }