Skip to contents

This function creates a dependabot.yaml file (configuration file) in the .github/ directory. This GitHub Action will be triggered once a week to check for dependency updates (used by any GitHub Action of the repository). If an update is available, this bot will open a Pull Request and user will be invited to review changes.

This function is called by add_github_action() to automatically create this configuration file if any GitHub Action is used.

Usage

add_dependabot(overwrite = FALSE, quiet = FALSE)

Arguments

overwrite

A logical value. If this file is already present and overwrite = TRUE, it will be erased and replaced. Default is FALSE.

quiet

A logical value. If TRUE messages are deleted. Default is FALSE.

Value

No return value.

Examples

if (FALSE) { # \dontrun{
add_dependabot()
} # }