Skip to contents

This function creates a DESCRIPTION file at the root of the project. This file contains metadata of the project. Some information (title, description, version, etc.) must be edited by hand. For more information: https://r-pkgs.org/description.html. User credentials can be passed as arguments but it is recommended to store them in the .Rprofile file of the project with set_credentials().

Usage

add_description(
  given = NULL,
  family = NULL,
  email = NULL,
  orcid = NULL,
  organisation = NULL,
  open = TRUE,
  overwrite = FALSE,
  quiet = FALSE
)

Arguments

given

a character of length 1. The given name of the user (considered as the maintainer and code owner of the project).

family

a character of length 1. The family name of the user (considered as the maintainer and code owner of the project).

email

a character of length 1. The email address of the user (considered as the maintainer and code owner of the project).

orcid

a character of length 1. The ORCID of the user (considered as the maintainer and code owner of the project).

organisation

A character of length 1. The name of the GitHub organisation to host the package. If NULL (default) the GitHub account will be used. This argument is used to set the URL of the package (hosted on GitHub).

open

A logical value. If TRUE (default) the file is opened in the editor.

overwrite

A logical value. If this file is already present and overwrite = TRUE, it will be erased and replaced. Default is FALSE.

quiet

A logical value. If TRUE messages are deleted. Default is FALSE.

Value

No return value.

Examples

if (FALSE) { # \dontrun{
add_description(organisation = "MySociety")
} # }