Add a Test coverage badge
Source:R/add_github_actions_codecov_badge.R
add_github_actions_codecov_badge.RdThis function adds a Test coverage badge to the README.Rmd. This
function must be run after add_github_action() which will setup
GitHub Actions to report the percentage of code cover by units tests.
Make sure that 1) a README.Rmd file exists at the project root and 2) it
contains a block starting with the line <!-- badges: start --> and ending
with the line <!-- badges: end -->.
Don't forget to re-render the README.md.