Skip to contents

This function creates an Issue template file (md) in the directory .github/ISSUE_TEMPLATE. These files preformat a GitHub Issue. Contributors can use these templates when they open new issues. For instance, you can format issue related to bug report, feature request, etc.

Usage

add_issue_template(name, open = FALSE, overwrite = FALSE, quiet = FALSE)

Arguments

name

A character of length 1. The name of the Issue Template to add. Run get_available_issue_templates() to list available Issue Templates.

open

A logical value. If TRUE (default) the file is opened in the editor.

overwrite

A logical value. If this file is already present and overwrite = TRUE, it will be erased and replaced. Default is FALSE.

quiet

A logical value. If TRUE messages are deleted. Default is FALSE.

Value

No return value.

Examples

if (FALSE) { # \dontrun{
add_issue_template(name = "feature_request")
} # }