Skip to contents

This function adds a license to the project. It will add the license name in the License field of the DESCRIPTION file and write the content of the license in a LICENSE.md file.

Usage

add_license(license = NULL, given = NULL, family = NULL, quiet = FALSE)

Arguments

license

A character of length 1. The license name. Run get_available_licenses()) to select an appropriate one.

given

a character of length 1. The given name of the user (considered as the maintainer and code owner of the project).

family

a character of length 1. The family name of the user (considered as the maintainer and code owner of the project).

quiet

A logical value. If TRUE messages are deleted. Default is FALSE.

Value

No return value.

Examples

if (FALSE) { # \dontrun{
add_license(license = "MIT")
add_license(license = "GPL (>= 2)")
} # }