This function creates a Make-like R file (make.R) at the root of the
project based on a template. To be used only if the project is a research
compendium. The content of this file provides some guidelines. See also
create_new_compendium() for further information.
Usage
add_makefile(
given = NULL,
family = NULL,
email = NULL,
open = TRUE,
overwrite = FALSE,
quiet = FALSE
)Arguments
- given
a
characterof length 1. The given name of the user (considered as the maintainer and code owner of the project).- family
a
characterof length 1. The family name of the user (considered as the maintainer and code owner of the project).a
characterof length 1. The email address of the user (considered as the maintainer and code owner of the project).- open
A logical value. If
TRUE(default) the file is opened in the editor.- overwrite
A logical value. If this file is already present and
overwrite = TRUE, it will be erased and replaced. Default isFALSE.- quiet
A logical value. If
TRUEmessages are deleted. Default isFALSE.