This function adds the minimal R version to the Depends field of the
DESCRIPTION file. This version corresponds to the higher version of R
among all dependencies. If no dependencies mentions minimal R version, the
DESCRIPTION is not modified.
See also
Other development functions:
add_dependabot(),
add_dependencies(),
add_github_action(),
add_to_buildignore(),
add_to_gitignore()