This function creates a README.Rmd file at the root of the project based
on a template. Once edited user needs to knit it into a README.md.
Usage
add_readme_rmd(
type = "package",
given = NULL,
family = NULL,
organisation = NULL,
open = TRUE,
overwrite = FALSE,
quiet = FALSE
)Arguments
- type
A character of length 1. If
package(default) a GitHubREADME.Rmdspecific to an R package will be created. Ifcompendiuma GitHubREADME.Rmdspecific to a research compendium will be created.- given
a
characterof length 1. The given name of the user (considered as the maintainer and code owner of the project).- family
a
characterof length 1. The family name of the user (considered as the maintainer and code owner of the project).- organisation
A character of length 1. The name of the GitHub organisation to host the package. If
NULL(default) the GitHub account will be used. This argument is used to set the URL of the package (hosted on GitHub).- open
A logical value. If
TRUE(default) the file is opened in the editor.- overwrite
A logical value. If this file is already present and
overwrite = TRUE, it will be erased and replaced. Default isFALSE.- quiet
A logical value. If
TRUEmessages are deleted. Default isFALSE.