This function creates a .gitignore file at the root of the project based on
a template (specific to R). If a .gitignore is already present, files to
be untracked by git are just added to this file.
See also
Other development functions:
add_dependabot(),
add_dependencies(),
add_github_action(),
add_r_depend(),
add_to_buildignore()