Skip to contents

This function creates a CODEOWNERS file in the folder .github/. This file is used to define individual that is responsible for code in the repository.

Usage

add_codeowners(open = FALSE, overwrite = FALSE, quiet = FALSE)

Arguments

open

A logical value. If TRUE (default) the file is opened in the editor.

overwrite

A logical value. If this file is already present and overwrite = TRUE, it will be erased and replaced. Default is FALSE.

quiet

A logical value. If TRUE messages are deleted. Default is FALSE.

Value

No return value.

Examples

if (FALSE) { # \dontrun{
add_codeowners()
} # }