This function adds a CRAN Status (i.e. CRAN version) badge to the
README.Rmd. If the package is not hosted on the CRAN the badge will
indicate not published on the CRAN.
Make sure that 1) a README.Rmd file exists at the project root and 2) it
contains a block starting with the line <!-- badges: start --> and ending
with the line <!-- badges: end -->.
Don't forget to re-render the README.md.
See also
Other adding badges:
add_codecov_badge(),
add_cran_downloads_badge(),
add_cran_total_download_badge(),
add_dependencies_badge(),
add_github_actions_check_badge(),
add_github_actions_codecov_badge(),
add_github_actions_pkgdown_badge(),
add_license_badge(),
add_lifecycle_badge(),
add_repostatus_badge()