This function creates a dependabot.yaml file (configuration file) in the
.github/ directory. This GitHub Action will be triggered once a week to
check for dependency updates (used by any GitHub Action of the repository).
If an update is available, this bot will open a Pull Request and user will
be invited to review changes.
This function is called by add_github_action() to automatically create
this configuration file if any GitHub Action is used.
See also
Other development functions:
add_dependencies(),
add_github_action(),
add_r_depend(),
add_to_buildignore(),
add_to_gitignore()