This function creates an Issue template file (md) in the directory
.github/ISSUE_TEMPLATE. These files preformat a GitHub Issue. Contributors
can use these templates when they open new issues. For instance, you can
format issue related to bug report, feature request, etc.
Arguments
- name
A character of length 1. The name of the Issue Template to add. Run
get_available_issue_templates()to list available Issue Templates.- open
A logical value. If
TRUE(default) the file is opened in the editor.- overwrite
A logical value. If this file is already present and
overwrite = TRUE, it will be erased and replaced. Default isFALSE.- quiet
A logical value. If
TRUEmessages are deleted. Default isFALSE.
See also
Other development functions:
add_dependabot(),
add_dependencies(),
add_github_action(),
add_r_depend(),
add_to_buildignore(),
add_to_gitignore()