This function adds a license to the project. It will add the license name
in the License field of the DESCRIPTION file and write the content of
the license in a LICENSE.md file.
Arguments
- license
A character of length 1. The license name. Run
get_available_licenses()) to select an appropriate one.- given
a
characterof length 1. The given name of the user (considered as the maintainer and code owner of the project).- family
a
characterof length 1. The family name of the user (considered as the maintainer and code owner of the project).- quiet
A logical value. If
TRUEmessages are deleted. Default isFALSE.