This function adds a license to the project. It will add the license name
in the License field of the DESCRIPTION file and write the content of
the license in the License.md file.
Arguments
- license
A character of length 1. The chosen license. Run
get_licenses()) to select an appropriate one.- given
A character of length 1. The given name of the copyright holder. Only required if
license = 'MIT'. If isNULL(default) andlicense = 'MIT', this function will try to retrieve the value of this parameter from the.Rprofilefile (edited withset_credentials()).- family
A character of length 1. The family name of the copyright holder. Only required if
license = 'MIT'. If isNULL(default) andlicense = 'MIT', this function will try to retrieve the value of this parameter from the.Rprofilefile (edited withset_credentials()).- quiet
A logical value. If
TRUEmessages are deleted. Default isFALSE.