Skip to contents

This function returns a list of the name of all available GitHub Actions. This is particularly useful to get the right spelling of the GitHub Action to be passed to add_github_action().

Usage

get_available_gh_actions()

Value

A character vector with the name of the available GitHub Actions in rcompendium.

Examples

get_available_gh_actions()
#> [1] "R-CMD-check"         "README.md"           "check-format"       
#> [4] "pkgdown"             "render-README"       "test-coverage"      
#> [7] "update-Rd-files"     "update-citation-cff" "update-codemeta"