This function returns a list of the name of all available GitHub Actions.
This is particularly useful to get the right spelling of the GitHub Action
to be passed to add_github_action().
See also
Other utilities functions:
get_all_dependencies(),
get_all_functions(),
get_licenses(),
get_minimal_r_version()