Skip to contents

This function returns a list of the name of all available Issue Templates. This is particularly useful to get the right spelling of the Issue Templates to be passed to add_issue_template().

Usage

get_available_issue_templates()

Value

A character vector with the name of the available Issue Templates in rcompendium.

Examples

get_available_issue_templates()
#> [1] "bug_report"      "feature_request"