List available ISSUE TEMPLATE
Source:R/get_available_issue_template.R
get_available_issue_templates.RdThis function returns a list of the name of all available Issue Templates.
This is particularly useful to get the right spelling of the Issue Templates
to be passed to add_issue_template().
See also
Other utilities functions:
get_all_dependencies(),
get_all_functions(),
get_available_gh_actions(),
get_licenses(),
get_minimal_r_version()